Index: src/arm/code-stubs-arm.h |
diff --git a/src/arm/code-stubs-arm.h b/src/arm/code-stubs-arm.h |
index c8d30e72e1a95d35e249a023ee97b0bd9ec0cbac..e7f6610fa183f47af8e4f78324fcd0c47c1a05d2 100644 |
--- a/src/arm/code-stubs-arm.h |
+++ b/src/arm/code-stubs-arm.h |
@@ -25,31 +25,22 @@ class StringHelper : public AllStatic { |
Register scratch, |
String::Encoding encoding); |
- // Compares two flat ASCII strings and returns result in r0. |
- static void GenerateCompareFlatAsciiStrings(MacroAssembler* masm, |
- Register left, |
- Register right, |
+ // Compares two flat one-byte strings and returns result in r0. |
+ static void GenerateCompareFlatOneByteStrings( |
+ MacroAssembler* masm, Register left, Register right, Register scratch1, |
+ Register scratch2, Register scratch3, Register scratch4); |
+ |
+ // Compares two flat one-byte strings for equality and returns result in r0. |
+ static void GenerateFlatOneByteStringEquals(MacroAssembler* masm, |
+ Register left, Register right, |
Register scratch1, |
Register scratch2, |
- Register scratch3, |
- Register scratch4); |
- |
- // Compares two flat ASCII strings for equality and returns result in r0. |
- static void GenerateFlatAsciiStringEquals(MacroAssembler* masm, |
- Register left, |
- Register right, |
- Register scratch1, |
- Register scratch2, |
- Register scratch3); |
+ Register scratch3); |
private: |
- static void GenerateAsciiCharsCompareLoop(MacroAssembler* masm, |
- Register left, |
- Register right, |
- Register length, |
- Register scratch1, |
- Register scratch2, |
- Label* chars_not_equal); |
+ static void GenerateOneByteCharsCompareLoop( |
+ MacroAssembler* masm, Register left, Register right, Register length, |
+ Register scratch1, Register scratch2, Label* chars_not_equal); |
DISALLOW_IMPLICIT_CONSTRUCTORS(StringHelper); |
}; |